@@ -16,6 +16,23 @@
 #include "layer-surface.h"
 #include "xdg-toplevel-surface.h"
 
+guint
+gtk_layer_get_major_version ()
+{
+    return GTK_LAYER_SHELL_MAJOR;
+}
+
+guint
+gtk_layer_get_minor_version ()
+{
+    return GTK_LAYER_SHELL_MINOR;
+}
+
+guint gtk_layer_get_micro_version ()
+{
+    return GTK_LAYER_SHELL_MICRO;
+}
+
 static
 LayerSurface* gtk_window_get_layer_surface (GtkWindow *window)
 {
@@ -48,6 +65,14 @@ gtk_layer_init_for_window (GtkWindow *window)
     }
 }
 
+struct zwlr_layer_surface_v1 *
+gtk_layer_get_zwlr_layer_surface_v1 (GtkWindow *window)
+{
+    LayerSurface *layer_surface = gtk_window_get_layer_surface (window);
+    if (!layer_surface) return NULL; // Error message already shown in gtk_window_get_layer_surface
+    return layer_surface_get_get_zwlr_layer_surface_v1 (layer_surface);
+}
+
 void
 gtk_layer_set_namespace (GtkWindow *window, char const* name_space)
 {
